@@ -1188,6 +1188,9 @@ class Update(MethodsInterface):
         if self.refresh_binhost:
             self.printWARNING(_("Update server was changed to %s") %
                               self.clVars.Get('cl_update_binhost'))
+        elif self.clVars.GetBool('update.cl_update_binhost_recheck_set'):
+            self.printSUCCESS(_("Update server %s") %
+                              self.clVars.Get('cl_update_binhost'))
         return True
 
     def update_binhost_list(self):
